hotelproto

package module
v0.0.0-...-6f6e013 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2024 License: MIT Imports: 8 Imported by: 9

README

hotel-proto

protobuf for hotel microservice

Documentation

Index

Constants

This section is empty.

Variables

var File_profile_proto protoreflect.FileDescriptor
var File_reservation_proto protoreflect.FileDescriptor
var File_search_proto protoreflect.FileDescriptor
var ProfileService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "hotelproto.ProfileService",
	HandlerType: (*ProfileServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetProfiles",
			Handler:    _ProfileService_GetProfiles_Handler,
		},
		{
			MethodName: "StoreProfile",
			Handler:    _ProfileService_StoreProfile_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "profile.proto",
}

ProfileService_ServiceDesc is the grpc.ServiceDesc for ProfileService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var RateService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "hotelproto.RateService",
	HandlerType: (*RateServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetRates",
			Handler:    _RateService_GetRates_Handler,
		},
		{
			MethodName: "StoreRate",
			Handler:    _RateService_StoreRate_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "rate.proto",
}

RateService_ServiceDesc is the grpc.ServiceDesc for RateService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var ReservationService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "hotelproto.ReservationService",
	HandlerType: (*ReservationServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "FrontendReservation",
			Handler:    _ReservationService_FrontendReservation_Handler,
		},
		{
			MethodName: "MakeReservation",
			Handler:    _ReservationService_MakeReservation_Handler,
		},
		{
			MethodName: "CheckAvailability",
			Handler:    _ReservationService_CheckAvailability_Handler,
		},
		{
			MethodName: "AddHotelAvailability",
			Handler:    _ReservationService_AddHotelAvailability_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "reservation.proto",
}

ReservationService_ServiceDesc is the grpc.ServiceDesc for ReservationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var SearchService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "hotelproto.SearchService",
	HandlerType: (*SearchServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "SearchHotels",
			Handler:    _SearchService_SearchHotels_Handler,
		},
		{
			MethodName: "Nearby",
			Handler:    _SearchService_Nearby_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "search.proto",
}

SearchService_ServiceDesc is the grpc.ServiceDesc for SearchService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var UserService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "hotelproto.UserService",
	HandlerType: (*UserServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "RegisterUser",
			Handler:    _UserService_RegisterUser_Handler,
		},
		{
			MethodName: "Login",
			Handler:    _UserService_Login_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "user.proto",
}

UserService_ServiceDesc is the grpc.ServiceDesc for UserService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterProfileServiceServer

func RegisterProfileServiceServer(s grpc.ServiceRegistrar, srv ProfileServiceServer)

func RegisterRateServiceServer

func RegisterRateServiceServer(s grpc.ServiceRegistrar, srv RateServiceServer)

func RegisterReservationServiceServer

func RegisterReservationServiceServer(s grpc.ServiceRegistrar, srv ReservationServiceServer)

func RegisterSearchServiceServer

func RegisterSearchServiceServer(s grpc.ServiceRegistrar, srv SearchServiceServer)

func RegisterUserServiceServer

func RegisterUserServiceServer(s grpc.ServiceRegistrar, srv UserServiceServer)

Types

type AddHotelAvailabilityRequest

type AddHotelAvailabilityRequest struct {
	HotelId  string `protobuf:"bytes,1,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	Capacity int32  `protobuf:"varint,2,opt,name=Capacity,proto3" json:"Capacity,omitempty"`
	// contains filtered or unexported fields
}

func (*AddHotelAvailabilityRequest) Descriptor deprecated

func (*AddHotelAvailabilityRequest) Descriptor() ([]byte, []int)

Deprecated: Use AddHotelAvailabilityRequest.ProtoReflect.Descriptor instead.

func (*AddHotelAvailabilityRequest) GetCapacity

func (x *AddHotelAvailabilityRequest) GetCapacity() int32

func (*AddHotelAvailabilityRequest) GetHotelId

func (x *AddHotelAvailabilityRequest) GetHotelId() string

func (*AddHotelAvailabilityRequest) ProtoMessage

func (*AddHotelAvailabilityRequest) ProtoMessage()

func (*AddHotelAvailabilityRequest) ProtoReflect

func (*AddHotelAvailabilityRequest) Reset

func (x *AddHotelAvailabilityRequest) Reset()

func (*AddHotelAvailabilityRequest) String

func (x *AddHotelAvailabilityRequest) String() string

type AddHotelAvailabilityResponse

type AddHotelAvailabilityResponse struct {
	HotelId string `protobuf:"bytes,1,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	// contains filtered or unexported fields
}

func (*AddHotelAvailabilityResponse) Descriptor deprecated

func (*AddHotelAvailabilityResponse) Descriptor() ([]byte, []int)

Deprecated: Use AddHotelAvailabilityResponse.ProtoReflect.Descriptor instead.

func (*AddHotelAvailabilityResponse) GetHotelId

func (x *AddHotelAvailabilityResponse) GetHotelId() string

func (*AddHotelAvailabilityResponse) ProtoMessage

func (*AddHotelAvailabilityResponse) ProtoMessage()

func (*AddHotelAvailabilityResponse) ProtoReflect

func (*AddHotelAvailabilityResponse) Reset

func (x *AddHotelAvailabilityResponse) Reset()

func (*AddHotelAvailabilityResponse) String

type CheckAvailabilityRequest

type CheckAvailabilityRequest struct {
	CustomerName string   `protobuf:"bytes,1,opt,name=CustomerName,proto3" json:"CustomerName,omitempty"`
	HotelIds     []string `protobuf:"bytes,2,rep,name=HotelIds,proto3" json:"HotelIds,omitempty"`
	InDate       string   `protobuf:"bytes,3,opt,name=InDate,proto3" json:"InDate,omitempty"`
	OutDate      string   `protobuf:"bytes,4,opt,name=OutDate,proto3" json:"OutDate,omitempty"`
	RoomNumber   int32    `protobuf:"varint,5,opt,name=RoomNumber,proto3" json:"RoomNumber,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckAvailabilityRequest) Descriptor deprecated

func (*CheckAvailabilityRequest) Descriptor() ([]byte, []int)

Deprecated: Use CheckAvailabilityRequest.ProtoReflect.Descriptor instead.

func (*CheckAvailabilityRequest) GetCustomerName

func (x *CheckAvailabilityRequest) GetCustomerName() string

func (*CheckAvailabilityRequest) GetHotelIds

func (x *CheckAvailabilityRequest) GetHotelIds() []string

func (*CheckAvailabilityRequest) GetInDate

func (x *CheckAvailabilityRequest) GetInDate() string

func (*CheckAvailabilityRequest) GetOutDate

func (x *CheckAvailabilityRequest) GetOutDate() string

func (*CheckAvailabilityRequest) GetRoomNumber

func (x *CheckAvailabilityRequest) GetRoomNumber() int32

func (*CheckAvailabilityRequest) ProtoMessage

func (*CheckAvailabilityRequest) ProtoMessage()

func (*CheckAvailabilityRequest) ProtoReflect

func (x *CheckAvailabilityRequest) ProtoReflect() protoreflect.Message

func (*CheckAvailabilityRequest) Reset

func (x *CheckAvailabilityRequest) Reset()

func (*CheckAvailabilityRequest) String

func (x *CheckAvailabilityRequest) String() string

type CheckAvailabilityResponse

type CheckAvailabilityResponse struct {
	HotelIds []string `protobuf:"bytes,1,rep,name=HotelIds,proto3" json:"HotelIds,omitempty"`
	// contains filtered or unexported fields
}

func (*CheckAvailabilityResponse) Descriptor deprecated

func (*CheckAvailabilityResponse) Descriptor() ([]byte, []int)

Deprecated: Use CheckAvailabilityResponse.ProtoReflect.Descriptor instead.

func (*CheckAvailabilityResponse) GetHotelIds

func (x *CheckAvailabilityResponse) GetHotelIds() []string

func (*CheckAvailabilityResponse) ProtoMessage

func (*CheckAvailabilityResponse) ProtoMessage()

func (*CheckAvailabilityResponse) ProtoReflect

func (*CheckAvailabilityResponse) Reset

func (x *CheckAvailabilityResponse) Reset()

func (*CheckAvailabilityResponse) String

func (x *CheckAvailabilityResponse) String() string

type FrontendReservationRequest

type FrontendReservationRequest struct {
	HotelId  string `protobuf:"bytes,1,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	InDate   string `protobuf:"bytes,2,opt,name=InDate,proto3" json:"InDate,omitempty"`
	OutDate  string `protobuf:"bytes,3,opt,name=OutDate,proto3" json:"OutDate,omitempty"`
	Rooms    int32  `protobuf:"varint,4,opt,name=Rooms,proto3" json:"Rooms,omitempty"`
	Username string `protobuf:"bytes,5,opt,name=Username,proto3" json:"Username,omitempty"`
	Password string `protobuf:"bytes,6,opt,name=Password,proto3" json:"Password,omitempty"`
	// contains filtered or unexported fields
}

func (*FrontendReservationRequest) Descriptor deprecated

func (*FrontendReservationRequest) Descriptor() ([]byte, []int)

Deprecated: Use FrontendReservationRequest.ProtoReflect.Descriptor instead.

func (*FrontendReservationRequest) GetHotelId

func (x *FrontendReservationRequest) GetHotelId() string

func (*FrontendReservationRequest) GetInDate

func (x *FrontendReservationRequest) GetInDate() string

func (*FrontendReservationRequest) GetOutDate

func (x *FrontendReservationRequest) GetOutDate() string

func (*FrontendReservationRequest) GetPassword

func (x *FrontendReservationRequest) GetPassword() string

func (*FrontendReservationRequest) GetRooms

func (x *FrontendReservationRequest) GetRooms() int32

func (*FrontendReservationRequest) GetUsername

func (x *FrontendReservationRequest) GetUsername() string

func (*FrontendReservationRequest) ProtoMessage

func (*FrontendReservationRequest) ProtoMessage()

func (*FrontendReservationRequest) ProtoReflect

func (*FrontendReservationRequest) Reset

func (x *FrontendReservationRequest) Reset()

func (*FrontendReservationRequest) String

func (x *FrontendReservationRequest) String() string

type FrontendReservationResponse

type FrontendReservationResponse struct {
	Success bool `protobuf:"varint,1,opt,name=Success,proto3" json:"Success,omitempty"`
	// contains filtered or unexported fields
}

func (*FrontendReservationResponse) Descriptor deprecated

func (*FrontendReservationResponse) Descriptor() ([]byte, []int)

Deprecated: Use FrontendReservationResponse.ProtoReflect.Descriptor instead.

func (*FrontendReservationResponse) GetSuccess

func (x *FrontendReservationResponse) GetSuccess() bool

func (*FrontendReservationResponse) ProtoMessage

func (*FrontendReservationResponse) ProtoMessage()

func (*FrontendReservationResponse) ProtoReflect

func (*FrontendReservationResponse) Reset

func (x *FrontendReservationResponse) Reset()

func (*FrontendReservationResponse) String

func (x *FrontendReservationResponse) String() string

type GetProfilesRequest

type GetProfilesRequest struct {
	HotelIds []string `protobuf:"bytes,1,rep,name=HotelIds,proto3" json:"HotelIds,omitempty"`
	// contains filtered or unexported fields
}

func (*GetProfilesRequest) Descriptor deprecated

func (*GetProfilesRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetProfilesRequest.ProtoReflect.Descriptor instead.

func (*GetProfilesRequest) GetHotelIds

func (x *GetProfilesRequest) GetHotelIds() []string

func (*GetProfilesRequest) ProtoMessage

func (*GetProfilesRequest) ProtoMessage()

func (*GetProfilesRequest) ProtoReflect

func (x *GetProfilesRequest) ProtoReflect() protoreflect.Message

func (*GetProfilesRequest) Reset

func (x *GetProfilesRequest) Reset()

func (*GetProfilesRequest) String

func (x *GetProfilesRequest) String() string

type GetProfilesResponse

type GetProfilesResponse struct {
	Profiles []*HotelProfile `protobuf:"bytes,1,rep,name=Profiles,proto3" json:"Profiles,omitempty"`
	// contains filtered or unexported fields
}

func (*GetProfilesResponse) Descriptor deprecated

func (*GetProfilesResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetProfilesResponse.ProtoReflect.Descriptor instead.

func (*GetProfilesResponse) GetProfiles

func (x *GetProfilesResponse) GetProfiles() []*HotelProfile

func (*GetProfilesResponse) ProtoMessage

func (*GetProfilesResponse) ProtoMessage()

func (*GetProfilesResponse) ProtoReflect

func (x *GetProfilesResponse) ProtoReflect() protoreflect.Message

func (*GetProfilesResponse) Reset

func (x *GetProfilesResponse) Reset()

func (*GetProfilesResponse) String

func (x *GetProfilesResponse) String() string

type GetRatesRequest

type GetRatesRequest struct {
	HotelIds []string `protobuf:"bytes,1,rep,name=HotelIds,proto3" json:"HotelIds,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRatesRequest) Descriptor deprecated

func (*GetRatesRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetRatesRequest.ProtoReflect.Descriptor instead.

func (*GetRatesRequest) GetHotelIds

func (x *GetRatesRequest) GetHotelIds() []string

func (*GetRatesRequest) ProtoMessage

func (*GetRatesRequest) ProtoMessage()

func (*GetRatesRequest) ProtoReflect

func (x *GetRatesRequest) ProtoReflect() protoreflect.Message

func (*GetRatesRequest) Reset

func (x *GetRatesRequest) Reset()

func (*GetRatesRequest) String

func (x *GetRatesRequest) String() string

type GetRatesResponse

type GetRatesResponse struct {
	Rates []*Rate `protobuf:"bytes,1,rep,name=Rates,proto3" json:"Rates,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRatesResponse) Descriptor deprecated

func (*GetRatesResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetRatesResponse.ProtoReflect.Descriptor instead.

func (*GetRatesResponse) GetRates

func (x *GetRatesResponse) GetRates() []*Rate

func (*GetRatesResponse) ProtoMessage

func (*GetRatesResponse) ProtoMessage()

func (*GetRatesResponse) ProtoReflect

func (x *GetRatesResponse) ProtoReflect() protoreflect.Message

func (*GetRatesResponse) Reset

func (x *GetRatesResponse) Reset()

func (*GetRatesResponse) String

func (x *GetRatesResponse) String() string

type HotelAvailability

type HotelAvailability struct {
	Capacity     int32          `protobuf:"varint,1,opt,name=Capacity,proto3" json:"Capacity,omitempty"`
	Reservations []*Reservation `protobuf:"bytes,2,rep,name=Reservations,proto3" json:"Reservations,omitempty"`
	// contains filtered or unexported fields
}

func (*HotelAvailability) Descriptor deprecated

func (*HotelAvailability) Descriptor() ([]byte, []int)

Deprecated: Use HotelAvailability.ProtoReflect.Descriptor instead.

func (*HotelAvailability) GetCapacity

func (x *HotelAvailability) GetCapacity() int32

func (*HotelAvailability) GetReservations

func (x *HotelAvailability) GetReservations() []*Reservation

func (*HotelAvailability) ProtoMessage

func (*HotelAvailability) ProtoMessage()

func (*HotelAvailability) ProtoReflect

func (x *HotelAvailability) ProtoReflect() protoreflect.Message

func (*HotelAvailability) Reset

func (x *HotelAvailability) Reset()

func (*HotelAvailability) String

func (x *HotelAvailability) String() string

type HotelProfile

type HotelProfile struct {
	HotelId string `protobuf:"bytes,1,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	Name    string `protobuf:"bytes,2,opt,name=Name,proto3" json:"Name,omitempty"`
	Phone   string `protobuf:"bytes,3,opt,name=Phone,proto3" json:"Phone,omitempty"`
	Info    string `protobuf:"bytes,4,opt,name=Info,proto3" json:"Info,omitempty"`
	// contains filtered or unexported fields
}

func (*HotelProfile) Descriptor deprecated

func (*HotelProfile) Descriptor() ([]byte, []int)

Deprecated: Use HotelProfile.ProtoReflect.Descriptor instead.

func (*HotelProfile) GetHotelId

func (x *HotelProfile) GetHotelId() string

func (*HotelProfile) GetInfo

func (x *HotelProfile) GetInfo() string

func (*HotelProfile) GetName

func (x *HotelProfile) GetName() string

func (*HotelProfile) GetPhone

func (x *HotelProfile) GetPhone() string

func (*HotelProfile) ProtoMessage

func (*HotelProfile) ProtoMessage()

func (*HotelProfile) ProtoReflect

func (x *HotelProfile) ProtoReflect() protoreflect.Message

func (*HotelProfile) Reset

func (x *HotelProfile) Reset()

func (*HotelProfile) String

func (x *HotelProfile) String() string

type LoginRequest

type LoginRequest struct {
	Username string `protobuf:"bytes,1,opt,name=Username,proto3" json:"Username,omitempty"`
	Password string `protobuf:"bytes,2,opt,name=Password,proto3" json:"Password,omitempty"`
	// contains filtered or unexported fields
}

func (*LoginRequest) Descriptor deprecated

func (*LoginRequest) Descriptor() ([]byte, []int)

Deprecated: Use LoginRequest.ProtoReflect.Descriptor instead.

func (*LoginRequest) GetPassword

func (x *LoginRequest) GetPassword() string

func (*LoginRequest) GetUsername

func (x *LoginRequest) GetUsername() string

func (*LoginRequest) ProtoMessage

func (*LoginRequest) ProtoMessage()

func (*LoginRequest) ProtoReflect

func (x *LoginRequest) ProtoReflect() protoreflect.Message

func (*LoginRequest) Reset

func (x *LoginRequest) Reset()

func (*LoginRequest) String

func (x *LoginRequest) String() string

type LoginResponse

type LoginResponse struct {
	Token string `protobuf:"bytes,1,opt,name=Token,proto3" json:"Token,omitempty"`
	// contains filtered or unexported fields
}

func (*LoginResponse) Descriptor deprecated

func (*LoginResponse) Descriptor() ([]byte, []int)

Deprecated: Use LoginResponse.ProtoReflect.Descriptor instead.

func (*LoginResponse) GetToken

func (x *LoginResponse) GetToken() string

func (*LoginResponse) ProtoMessage

func (*LoginResponse) ProtoMessage()

func (*LoginResponse) ProtoReflect

func (x *LoginResponse) ProtoReflect() protoreflect.Message

func (*LoginResponse) Reset

func (x *LoginResponse) Reset()

func (*LoginResponse) String

func (x *LoginResponse) String() string

type MakeReservationRequest

type MakeReservationRequest struct {
	CustomerName string `protobuf:"bytes,1,opt,name=CustomerName,proto3" json:"CustomerName,omitempty"`
	HotelId      string `protobuf:"bytes,2,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	InDate       string `protobuf:"bytes,3,opt,name=InDate,proto3" json:"InDate,omitempty"`
	OutDate      string `protobuf:"bytes,4,opt,name=OutDate,proto3" json:"OutDate,omitempty"`
	RoomNumber   int32  `protobuf:"varint,5,opt,name=RoomNumber,proto3" json:"RoomNumber,omitempty"`
	// contains filtered or unexported fields
}

func (*MakeReservationRequest) Descriptor deprecated

func (*MakeReservationRequest) Descriptor() ([]byte, []int)

Deprecated: Use MakeReservationRequest.ProtoReflect.Descriptor instead.

func (*MakeReservationRequest) GetCustomerName

func (x *MakeReservationRequest) GetCustomerName() string

func (*MakeReservationRequest) GetHotelId

func (x *MakeReservationRequest) GetHotelId() string

func (*MakeReservationRequest) GetInDate

func (x *MakeReservationRequest) GetInDate() string

func (*MakeReservationRequest) GetOutDate

func (x *MakeReservationRequest) GetOutDate() string

func (*MakeReservationRequest) GetRoomNumber

func (x *MakeReservationRequest) GetRoomNumber() int32

func (*MakeReservationRequest) ProtoMessage

func (*MakeReservationRequest) ProtoMessage()

func (*MakeReservationRequest) ProtoReflect

func (x *MakeReservationRequest) ProtoReflect() protoreflect.Message

func (*MakeReservationRequest) Reset

func (x *MakeReservationRequest) Reset()

func (*MakeReservationRequest) String

func (x *MakeReservationRequest) String() string

type MakeReservationResponse

type MakeReservationResponse struct {
	Success bool `protobuf:"varint,1,opt,name=Success,proto3" json:"Success,omitempty"`
	// contains filtered or unexported fields
}

func (*MakeReservationResponse) Descriptor deprecated

func (*MakeReservationResponse) Descriptor() ([]byte, []int)

Deprecated: Use MakeReservationResponse.ProtoReflect.Descriptor instead.

func (*MakeReservationResponse) GetSuccess

func (x *MakeReservationResponse) GetSuccess() bool

func (*MakeReservationResponse) ProtoMessage

func (*MakeReservationResponse) ProtoMessage()

func (*MakeReservationResponse) ProtoReflect

func (x *MakeReservationResponse) ProtoReflect() protoreflect.Message

func (*MakeReservationResponse) Reset

func (x *MakeReservationResponse) Reset()

func (*MakeReservationResponse) String

func (x *MakeReservationResponse) String() string

type NearbyRequest

type NearbyRequest struct {
	InDate   string `protobuf:"bytes,1,opt,name=InDate,proto3" json:"InDate,omitempty"`
	OutDate  string `protobuf:"bytes,2,opt,name=OutDate,proto3" json:"OutDate,omitempty"`
	Location string `protobuf:"bytes,3,opt,name=Location,proto3" json:"Location,omitempty"`
	// contains filtered or unexported fields
}

func (*NearbyRequest) Descriptor deprecated

func (*NearbyRequest) Descriptor() ([]byte, []int)

Deprecated: Use NearbyRequest.ProtoReflect.Descriptor instead.

func (*NearbyRequest) GetInDate

func (x *NearbyRequest) GetInDate() string

func (*NearbyRequest) GetLocation

func (x *NearbyRequest) GetLocation() string

func (*NearbyRequest) GetOutDate

func (x *NearbyRequest) GetOutDate() string

func (*NearbyRequest) ProtoMessage

func (*NearbyRequest) ProtoMessage()

func (*NearbyRequest) ProtoReflect

func (x *NearbyRequest) ProtoReflect() protoreflect.Message

func (*NearbyRequest) Reset

func (x *NearbyRequest) Reset()

func (*NearbyRequest) String

func (x *NearbyRequest) String() string

type NearbyResponse

type NearbyResponse struct {
	Rates []*Rate `protobuf:"bytes,1,rep,name=Rates,proto3" json:"Rates,omitempty"`
	// contains filtered or unexported fields
}

func (*NearbyResponse) Descriptor deprecated

func (*NearbyResponse) Descriptor() ([]byte, []int)

Deprecated: Use NearbyResponse.ProtoReflect.Descriptor instead.

func (*NearbyResponse) GetRates

func (x *NearbyResponse) GetRates() []*Rate

func (*NearbyResponse) ProtoMessage

func (*NearbyResponse) ProtoMessage()

func (*NearbyResponse) ProtoReflect

func (x *NearbyResponse) ProtoReflect() protoreflect.Message

func (*NearbyResponse) Reset

func (x *NearbyResponse) Reset()

func (*NearbyResponse) String

func (x *NearbyResponse) String() string

type ProfileServiceClient

type ProfileServiceClient interface {
	GetProfiles(ctx context.Context, in *GetProfilesRequest, opts ...grpc.CallOption) (*GetProfilesResponse, error)
	StoreProfile(ctx context.Context, in *StoreProfileRequest, opts ...grpc.CallOption) (*StoreProfileResponse, error)
}

ProfileServiceClient is the client API for ProfileService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ProfileServiceServer

type ProfileServiceServer interface {
	GetProfiles(context.Context, *GetProfilesRequest) (*GetProfilesResponse, error)
	StoreProfile(context.Context, *StoreProfileRequest) (*StoreProfileResponse, error)
	// contains filtered or unexported methods
}

ProfileServiceServer is the server API for ProfileService service. All implementations must embed UnimplementedProfileServiceServer for forward compatibility

type Rate

type Rate struct {
	HotelId string `protobuf:"bytes,1,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	Price   int32  `protobuf:"varint,2,opt,name=Price,proto3" json:"Price,omitempty"`
	// contains filtered or unexported fields
}

func (*Rate) Descriptor deprecated

func (*Rate) Descriptor() ([]byte, []int)

Deprecated: Use Rate.ProtoReflect.Descriptor instead.

func (*Rate) GetHotelId

func (x *Rate) GetHotelId() string

func (*Rate) GetPrice

func (x *Rate) GetPrice() int32

func (*Rate) ProtoMessage

func (*Rate) ProtoMessage()

func (*Rate) ProtoReflect

func (x *Rate) ProtoReflect() protoreflect.Message

func (*Rate) Reset

func (x *Rate) Reset()

func (*Rate) String

func (x *Rate) String() string

type RateServiceClient

type RateServiceClient interface {
	GetRates(ctx context.Context, in *GetRatesRequest, opts ...grpc.CallOption) (*GetRatesResponse, error)
	StoreRate(ctx context.Context, in *StoreRateRequest, opts ...grpc.CallOption) (*StoreRateResponse, error)
}

RateServiceClient is the client API for RateService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type RateServiceServer

type RateServiceServer interface {
	GetRates(context.Context, *GetRatesRequest) (*GetRatesResponse, error)
	StoreRate(context.Context, *StoreRateRequest) (*StoreRateResponse, error)
	// contains filtered or unexported methods
}

RateServiceServer is the server API for RateService service. All implementations must embed UnimplementedRateServiceServer for forward compatibility

type RegisterUserRequest

type RegisterUserRequest struct {
	Username string `protobuf:"bytes,1,opt,name=Username,proto3" json:"Username,omitempty"`
	Password string `protobuf:"bytes,2,opt,name=Password,proto3" json:"Password,omitempty"`
	// contains filtered or unexported fields
}

func (*RegisterUserRequest) Descriptor deprecated

func (*RegisterUserRequest) Descriptor() ([]byte, []int)

Deprecated: Use RegisterUserRequest.ProtoReflect.Descriptor instead.

func (*RegisterUserRequest) GetPassword

func (x *RegisterUserRequest) GetPassword() string

func (*RegisterUserRequest) GetUsername

func (x *RegisterUserRequest) GetUsername() string

func (*RegisterUserRequest) ProtoMessage

func (*RegisterUserRequest) ProtoMessage()

func (*RegisterUserRequest) ProtoReflect

func (x *RegisterUserRequest) ProtoReflect() protoreflect.Message

func (*RegisterUserRequest) Reset

func (x *RegisterUserRequest) Reset()

func (*RegisterUserRequest) String

func (x *RegisterUserRequest) String() string

type RegisterUserResponse

type RegisterUserResponse struct {
	Ok bool `protobuf:"varint,1,opt,name=Ok,proto3" json:"Ok,omitempty"`
	// contains filtered or unexported fields
}

func (*RegisterUserResponse) Descriptor deprecated

func (*RegisterUserResponse) Descriptor() ([]byte, []int)

Deprecated: Use RegisterUserResponse.ProtoReflect.Descriptor instead.

func (*RegisterUserResponse) GetOk

func (x *RegisterUserResponse) GetOk() bool

func (*RegisterUserResponse) ProtoMessage

func (*RegisterUserResponse) ProtoMessage()

func (*RegisterUserResponse) ProtoReflect

func (x *RegisterUserResponse) ProtoReflect() protoreflect.Message

func (*RegisterUserResponse) Reset

func (x *RegisterUserResponse) Reset()

func (*RegisterUserResponse) String

func (x *RegisterUserResponse) String() string

type Reservation

type Reservation struct {
	CustomerName string `protobuf:"bytes,1,opt,name=CustomerName,proto3" json:"CustomerName,omitempty"`
	InDate       string `protobuf:"bytes,2,opt,name=InDate,proto3" json:"InDate,omitempty"`
	OutDate      string `protobuf:"bytes,3,opt,name=OutDate,proto3" json:"OutDate,omitempty"`
	RoomNumber   int32  `protobuf:"varint,4,opt,name=RoomNumber,proto3" json:"RoomNumber,omitempty"`
	// contains filtered or unexported fields
}

func (*Reservation) Descriptor deprecated

func (*Reservation) Descriptor() ([]byte, []int)

Deprecated: Use Reservation.ProtoReflect.Descriptor instead.

func (*Reservation) GetCustomerName

func (x *Reservation) GetCustomerName() string

func (*Reservation) GetInDate

func (x *Reservation) GetInDate() string

func (*Reservation) GetOutDate

func (x *Reservation) GetOutDate() string

func (*Reservation) GetRoomNumber

func (x *Reservation) GetRoomNumber() int32

func (*Reservation) ProtoMessage

func (*Reservation) ProtoMessage()

func (*Reservation) ProtoReflect

func (x *Reservation) ProtoReflect() protoreflect.Message

func (*Reservation) Reset

func (x *Reservation) Reset()

func (*Reservation) String

func (x *Reservation) String() string

type ReservationServiceClient

type ReservationServiceClient interface {
	FrontendReservation(ctx context.Context, in *FrontendReservationRequest, opts ...grpc.CallOption) (*FrontendReservationResponse, error)
	MakeReservation(ctx context.Context, in *MakeReservationRequest, opts ...grpc.CallOption) (*MakeReservationResponse, error)
	CheckAvailability(ctx context.Context, in *CheckAvailabilityRequest, opts ...grpc.CallOption) (*CheckAvailabilityResponse, error)
	AddHotelAvailability(ctx context.Context, in *AddHotelAvailabilityRequest, opts ...grpc.CallOption) (*AddHotelAvailabilityResponse, error)
}

ReservationServiceClient is the client API for ReservationService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ReservationServiceServer

type ReservationServiceServer interface {
	FrontendReservation(context.Context, *FrontendReservationRequest) (*FrontendReservationResponse, error)
	MakeReservation(context.Context, *MakeReservationRequest) (*MakeReservationResponse, error)
	CheckAvailability(context.Context, *CheckAvailabilityRequest) (*CheckAvailabilityResponse, error)
	AddHotelAvailability(context.Context, *AddHotelAvailabilityRequest) (*AddHotelAvailabilityResponse, error)
	// contains filtered or unexported methods
}

ReservationServiceServer is the server API for ReservationService service. All implementations must embed UnimplementedReservationServiceServer for forward compatibility

type SearchHotelsRequest

type SearchHotelsRequest struct {
	InDate   string `protobuf:"bytes,1,opt,name=InDate,proto3" json:"InDate,omitempty"`
	OutDate  string `protobuf:"bytes,2,opt,name=OutDate,proto3" json:"OutDate,omitempty"`
	Location string `protobuf:"bytes,3,opt,name=Location,proto3" json:"Location,omitempty"`
	// contains filtered or unexported fields
}

func (*SearchHotelsRequest) Descriptor deprecated

func (*SearchHotelsRequest) Descriptor() ([]byte, []int)

Deprecated: Use SearchHotelsRequest.ProtoReflect.Descriptor instead.

func (*SearchHotelsRequest) GetInDate

func (x *SearchHotelsRequest) GetInDate() string

func (*SearchHotelsRequest) GetLocation

func (x *SearchHotelsRequest) GetLocation() string

func (*SearchHotelsRequest) GetOutDate

func (x *SearchHotelsRequest) GetOutDate() string

func (*SearchHotelsRequest) ProtoMessage

func (*SearchHotelsRequest) ProtoMessage()

func (*SearchHotelsRequest) ProtoReflect

func (x *SearchHotelsRequest) ProtoReflect() protoreflect.Message

func (*SearchHotelsRequest) Reset

func (x *SearchHotelsRequest) Reset()

func (*SearchHotelsRequest) String

func (x *SearchHotelsRequest) String() string

type SearchHotelsResponse

type SearchHotelsResponse struct {
	Profiles []*HotelProfile `protobuf:"bytes,1,rep,name=Profiles,proto3" json:"Profiles,omitempty"`
	// contains filtered or unexported fields
}

func (*SearchHotelsResponse) Descriptor deprecated

func (*SearchHotelsResponse) Descriptor() ([]byte, []int)

Deprecated: Use SearchHotelsResponse.ProtoReflect.Descriptor instead.

func (*SearchHotelsResponse) GetProfiles

func (x *SearchHotelsResponse) GetProfiles() []*HotelProfile

func (*SearchHotelsResponse) ProtoMessage

func (*SearchHotelsResponse) ProtoMessage()

func (*SearchHotelsResponse) ProtoReflect

func (x *SearchHotelsResponse) ProtoReflect() protoreflect.Message

func (*SearchHotelsResponse) Reset

func (x *SearchHotelsResponse) Reset()

func (*SearchHotelsResponse) String

func (x *SearchHotelsResponse) String() string

type SearchServiceClient

type SearchServiceClient interface {
	SearchHotels(ctx context.Context, in *SearchHotelsRequest, opts ...grpc.CallOption) (*SearchHotelsResponse, error)
	Nearby(ctx context.Context, in *NearbyRequest, opts ...grpc.CallOption) (*NearbyResponse, error)
}

SearchServiceClient is the client API for SearchService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type SearchServiceServer

type SearchServiceServer interface {
	SearchHotels(context.Context, *SearchHotelsRequest) (*SearchHotelsResponse, error)
	Nearby(context.Context, *NearbyRequest) (*NearbyResponse, error)
	// contains filtered or unexported methods
}

SearchServiceServer is the server API for SearchService service. All implementations must embed UnimplementedSearchServiceServer for forward compatibility

type StoreHotelLocationRequest

type StoreHotelLocationRequest struct {
	HotelId  string `protobuf:"bytes,1,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	Location string `protobuf:"bytes,2,opt,name=Location,proto3" json:"Location,omitempty"`
	// contains filtered or unexported fields
}

func (*StoreHotelLocationRequest) Descriptor deprecated

func (*StoreHotelLocationRequest) Descriptor() ([]byte, []int)

Deprecated: Use StoreHotelLocationRequest.ProtoReflect.Descriptor instead.

func (*StoreHotelLocationRequest) GetHotelId

func (x *StoreHotelLocationRequest) GetHotelId() string

func (*StoreHotelLocationRequest) GetLocation

func (x *StoreHotelLocationRequest) GetLocation() string

func (*StoreHotelLocationRequest) ProtoMessage

func (*StoreHotelLocationRequest) ProtoMessage()

func (*StoreHotelLocationRequest) ProtoReflect

func (*StoreHotelLocationRequest) Reset

func (x *StoreHotelLocationRequest) Reset()

func (*StoreHotelLocationRequest) String

func (x *StoreHotelLocationRequest) String() string

type StoreHotelLocationResponse

type StoreHotelLocationResponse struct {
	HotelId string `protobuf:"bytes,1,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	// contains filtered or unexported fields
}

func (*StoreHotelLocationResponse) Descriptor deprecated

func (*StoreHotelLocationResponse) Descriptor() ([]byte, []int)

Deprecated: Use StoreHotelLocationResponse.ProtoReflect.Descriptor instead.

func (*StoreHotelLocationResponse) GetHotelId

func (x *StoreHotelLocationResponse) GetHotelId() string

func (*StoreHotelLocationResponse) ProtoMessage

func (*StoreHotelLocationResponse) ProtoMessage()

func (*StoreHotelLocationResponse) ProtoReflect

func (*StoreHotelLocationResponse) Reset

func (x *StoreHotelLocationResponse) Reset()

func (*StoreHotelLocationResponse) String

func (x *StoreHotelLocationResponse) String() string

type StoreHotelRequest

type StoreHotelRequest struct {
	HotelId  string `protobuf:"bytes,1,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	Name     string `protobuf:"bytes,2,opt,name=Name,proto3" json:"Name,omitempty"`
	Phone    string `protobuf:"bytes,3,opt,name=Phone,proto3" json:"Phone,omitempty"`
	Location string `protobuf:"bytes,4,opt,name=Location,proto3" json:"Location,omitempty"`
	Rate     int32  `protobuf:"varint,5,opt,name=Rate,proto3" json:"Rate,omitempty"`
	Capacity int32  `protobuf:"varint,6,opt,name=Capacity,proto3" json:"Capacity,omitempty"`
	Info     string `protobuf:"bytes,7,opt,name=Info,proto3" json:"Info,omitempty"`
	// contains filtered or unexported fields
}

func (*StoreHotelRequest) Descriptor deprecated

func (*StoreHotelRequest) Descriptor() ([]byte, []int)

Deprecated: Use StoreHotelRequest.ProtoReflect.Descriptor instead.

func (*StoreHotelRequest) GetCapacity

func (x *StoreHotelRequest) GetCapacity() int32

func (*StoreHotelRequest) GetHotelId

func (x *StoreHotelRequest) GetHotelId() string

func (*StoreHotelRequest) GetInfo

func (x *StoreHotelRequest) GetInfo() string

func (*StoreHotelRequest) GetLocation

func (x *StoreHotelRequest) GetLocation() string

func (*StoreHotelRequest) GetName

func (x *StoreHotelRequest) GetName() string

func (*StoreHotelRequest) GetPhone

func (x *StoreHotelRequest) GetPhone() string

func (*StoreHotelRequest) GetRate

func (x *StoreHotelRequest) GetRate() int32

func (*StoreHotelRequest) ProtoMessage

func (*StoreHotelRequest) ProtoMessage()

func (*StoreHotelRequest) ProtoReflect

func (x *StoreHotelRequest) ProtoReflect() protoreflect.Message

func (*StoreHotelRequest) Reset

func (x *StoreHotelRequest) Reset()

func (*StoreHotelRequest) String

func (x *StoreHotelRequest) String() string

type StoreHotelResponse

type StoreHotelResponse struct {
	HotelId string `protobuf:"bytes,1,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	// contains filtered or unexported fields
}

func (*StoreHotelResponse) Descriptor deprecated

func (*StoreHotelResponse) Descriptor() ([]byte, []int)

Deprecated: Use StoreHotelResponse.ProtoReflect.Descriptor instead.

func (*StoreHotelResponse) GetHotelId

func (x *StoreHotelResponse) GetHotelId() string

func (*StoreHotelResponse) ProtoMessage

func (*StoreHotelResponse) ProtoMessage()

func (*StoreHotelResponse) ProtoReflect

func (x *StoreHotelResponse) ProtoReflect() protoreflect.Message

func (*StoreHotelResponse) Reset

func (x *StoreHotelResponse) Reset()

func (*StoreHotelResponse) String

func (x *StoreHotelResponse) String() string

type StoreProfileRequest

type StoreProfileRequest struct {
	Profile *HotelProfile `protobuf:"bytes,1,opt,name=Profile,proto3" json:"Profile,omitempty"`
	// contains filtered or unexported fields
}

func (*StoreProfileRequest) Descriptor deprecated

func (*StoreProfileRequest) Descriptor() ([]byte, []int)

Deprecated: Use StoreProfileRequest.ProtoReflect.Descriptor instead.

func (*StoreProfileRequest) GetProfile

func (x *StoreProfileRequest) GetProfile() *HotelProfile

func (*StoreProfileRequest) ProtoMessage

func (*StoreProfileRequest) ProtoMessage()

func (*StoreProfileRequest) ProtoReflect

func (x *StoreProfileRequest) ProtoReflect() protoreflect.Message

func (*StoreProfileRequest) Reset

func (x *StoreProfileRequest) Reset()

func (*StoreProfileRequest) String

func (x *StoreProfileRequest) String() string

type StoreProfileResponse

type StoreProfileResponse struct {
	HotelId string `protobuf:"bytes,1,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	// contains filtered or unexported fields
}

func (*StoreProfileResponse) Descriptor deprecated

func (*StoreProfileResponse) Descriptor() ([]byte, []int)

Deprecated: Use StoreProfileResponse.ProtoReflect.Descriptor instead.

func (*StoreProfileResponse) GetHotelId

func (x *StoreProfileResponse) GetHotelId() string

func (*StoreProfileResponse) ProtoMessage

func (*StoreProfileResponse) ProtoMessage()

func (*StoreProfileResponse) ProtoReflect

func (x *StoreProfileResponse) ProtoReflect() protoreflect.Message

func (*StoreProfileResponse) Reset

func (x *StoreProfileResponse) Reset()

func (*StoreProfileResponse) String

func (x *StoreProfileResponse) String() string

type StoreRateRequest

type StoreRateRequest struct {
	Rate *Rate `protobuf:"bytes,1,opt,name=Rate,proto3" json:"Rate,omitempty"`
	// contains filtered or unexported fields
}

func (*StoreRateRequest) Descriptor deprecated

func (*StoreRateRequest) Descriptor() ([]byte, []int)

Deprecated: Use StoreRateRequest.ProtoReflect.Descriptor instead.

func (*StoreRateRequest) GetRate

func (x *StoreRateRequest) GetRate() *Rate

func (*StoreRateRequest) ProtoMessage

func (*StoreRateRequest) ProtoMessage()

func (*StoreRateRequest) ProtoReflect

func (x *StoreRateRequest) ProtoReflect() protoreflect.Message

func (*StoreRateRequest) Reset

func (x *StoreRateRequest) Reset()

func (*StoreRateRequest) String

func (x *StoreRateRequest) String() string

type StoreRateResponse

type StoreRateResponse struct {
	HotelId string `protobuf:"bytes,1,opt,name=HotelId,proto3" json:"HotelId,omitempty"`
	// contains filtered or unexported fields
}

func (*StoreRateResponse) Descriptor deprecated

func (*StoreRateResponse) Descriptor() ([]byte, []int)

Deprecated: Use StoreRateResponse.ProtoReflect.Descriptor instead.

func (*StoreRateResponse) GetHotelId

func (x *StoreRateResponse) GetHotelId() string

func (*StoreRateResponse) ProtoMessage

func (*StoreRateResponse) ProtoMessage()

func (*StoreRateResponse) ProtoReflect

func (x *StoreRateResponse) ProtoReflect() protoreflect.Message

func (*StoreRateResponse) Reset

func (x *StoreRateResponse) Reset()

func (*StoreRateResponse) String

func (x *StoreRateResponse) String() string

type UnimplementedProfileServiceServer

type UnimplementedProfileServiceServer struct {
}

UnimplementedProfileServiceServer must be embedded to have forward compatible implementations.

func (UnimplementedProfileServiceServer) GetProfiles

func (UnimplementedProfileServiceServer) StoreProfile

type UnimplementedRateServiceServer

type UnimplementedRateServiceServer struct {
}

UnimplementedRateServiceServer must be embedded to have forward compatible implementations.

func (UnimplementedRateServiceServer) GetRates

func (UnimplementedRateServiceServer) StoreRate

type UnimplementedReservationServiceServer

type UnimplementedReservationServiceServer struct {
}

UnimplementedReservationServiceServer must be embedded to have forward compatible implementations.

func (UnimplementedReservationServiceServer) AddHotelAvailability

func (UnimplementedReservationServiceServer) CheckAvailability

func (UnimplementedReservationServiceServer) FrontendReservation

func (UnimplementedReservationServiceServer) MakeReservation

type UnimplementedSearchServiceServer

type UnimplementedSearchServiceServer struct {
}

UnimplementedSearchServiceServer must be embedded to have forward compatible implementations.

func (UnimplementedSearchServiceServer) Nearby

func (UnimplementedSearchServiceServer) SearchHotels

type UnimplementedUserServiceServer

type UnimplementedUserServiceServer struct {
}

UnimplementedUserServiceServer must be embedded to have forward compatible implementations.

func (UnimplementedUserServiceServer) Login

func (UnimplementedUserServiceServer) RegisterUser

type UnsafeProfileServiceServer

type UnsafeProfileServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeProfileServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ProfileServiceServer will result in compilation errors.

type UnsafeRateServiceServer

type UnsafeRateServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeRateServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RateServiceServer will result in compilation errors.

type UnsafeReservationServiceServer

type UnsafeReservationServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeReservationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ReservationServiceServer will result in compilation errors.

type UnsafeSearchServiceServer

type UnsafeSearchServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeSearchServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SearchServiceServer will result in compilation errors.

type UnsafeUserServiceServer

type UnsafeUserServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeUserServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UserServiceServer will result in compilation errors.

type UserServiceClient

type UserServiceClient interface {
	RegisterUser(ctx context.Context, in *RegisterUserRequest, opts ...grpc.CallOption) (*RegisterUserResponse, error)
	Login(ctx context.Context, in *LoginRequest, opts ...grpc.CallOption) (*LoginResponse, error)
}

UserServiceClient is the client API for UserService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type UserServiceServer

type UserServiceServer interface {
	RegisterUser(context.Context, *RegisterUserRequest) (*RegisterUserResponse, error)
	Login(context.Context, *LoginRequest) (*LoginResponse, error)
	// contains filtered or unexported methods
}

UserServiceServer is the server API for UserService service. All implementations must embed UnimplementedUserServiceServer for forward compatibility

Jump to